@@ -1,5 +1,6 @@
 from warnings import warn
-from ctypes import c_uint8, c_uint16, c_int32, c_uint32, byref, c_double
+from ctypes import c_bool, c_uint8, c_uint16, c_int32, c_uint32, c_double
+from ctypes import byref
 from typing import Dict, Union, Optional
 from enum import IntEnum, unique
 from . import _MPuLib, _check_limits
@@ -16,9 +17,9 @@ class CardEmulationMode(IntEnum):
     SIM_MODE_DAQ2 = 5
 
 
-def MPC_ChannelOpen(mode: CardEmulationMode =
-                    CardEmulationMode.SIM_MODE_ANALOG_IN) \
-                    -> None:
+def MPC_ChannelOpen(
+        mode: CardEmulationMode = CardEmulationMode.SIM_MODE_ANALOG_IN
+        ) -> None:
     """Opens card emulation
 
     Parameters
@@ -42,9 +43,10 @@ class CardEmulationChannelDirection(IntEnum):
     CHANNEL_PURGE_TX_RX = 3
 
 
-def MPC_ChannelFlush(direction: CardEmulationChannelDirection =
-                     CardEmulationChannelDirection.CHANNEL_PURGE_TX_RX) \
-                     -> None:
+def MPC_ChannelFlush(
+        direction: CardEmulationChannelDirection =
+        CardEmulationChannelDirection.CHANNEL_PURGE_TX_RX
+        ) -> None:
     """Flushes card emulation channel
 
     Parameters
@@ -75,7 +77,9 @@ class NfcLoad(IntEnum):
     ANTENNA_LOAD_820 = 820
 
 
-def MPC_SelectLoadAntennaNfc(load: NfcLoad) -> None:
+def MPC_SelectLoadAntennaNfc(
+        load: NfcLoad
+        ) -> None:
     """Selects the electro-magnetic load on NFC antenna
 
     Parameters
@@ -90,8 +94,10 @@ def MPC_SelectLoadAntennaNfc(load: NfcLoad) -> None:
         c_uint16(load)))
 
 
-def MPC_SetLMAForCardEmulation(low_voltage: float,
-                               high_voltage: float) -> None:
+def MPC_SetLMAForCardEmulation(
+        low_voltage: float,
+        high_voltage: float
+        ) -> None:
     """Selects LMA voltage value
 
     Parameters
@@ -111,8 +117,10 @@ def MPC_SetLMAForCardEmulation(low_voltage: float,
         c_int32(high_voltage_mV)))
 
 
-def MPC_SetLMAForEMD(low_voltage: float,
-                     high_voltage: float) -> None:
+def MPC_SetLMAForEMD(
+        low_voltage: float,
+        high_voltage: float
+        ) -> None:
     """Selects LMA voltage value during EMD generation
 
     Parameters
@@ -143,7 +151,9 @@ class SubcarrierFrequency(IntEnum):
     SubCarrier6780 = 6780
 
 
-def MPC_SetUpReferencePICC(subcarrier: Optional[SubcarrierFrequency]) -> None:
+def MPC_SetUpReferencePICC(
+        subcarrier: Optional[SubcarrierFrequency]
+        ) -> None:
     """Generates a sub-carrier frequency
 
     Parameters
@@ -154,7 +164,7 @@ def MPC_SetUpReferencePICC(subcarrier: Optional[SubcarrierFrequency]) -> None:
     if subcarrier is None:
         CTS3Exception._check_error(_MPuLib.MPC_SetUpReferencePICC(
             c_uint8(0),
-            c_uint8(0),
+            c_bool(False),
             c_uint32(0)))
     else:
         if not isinstance(subcarrier, SubcarrierFrequency):
@@ -162,11 +172,13 @@ def MPC_SetUpReferencePICC(subcarrier: Optional[SubcarrierFrequency]) -> None:
                             'SubcarrierFrequency IntEnum')
         CTS3Exception._check_error(_MPuLib.MPC_SetUpReferencePICC(
             c_uint8(0),
-            c_uint8(1),
+            c_bool(True),
             c_uint32(subcarrier)))
 
 
-def MPC_SetPCDPauseMax(pause_duration_fc: float) -> None:
+def MPC_SetPCDPauseMax(
+        pause_duration_fc: float
+        ) -> None:
     """Selects the maximum allowed duration of PCD Type A pause
 
     Parameters
@@ -182,7 +194,9 @@ def MPC_SetPCDPauseMax(pause_duration_fc: float) -> None:
         c_uint16(pause_duration_10fc)))
 
 
-def MPC_SetDetectionPCDModulation(ask_filter: int) -> None:
+def MPC_SetDetectionPCDModulation(
+        ask_filter: int
+        ) -> None:
     """Changes the PCD ASK detection filter characteristics
 
     Parameters
@@ -213,9 +227,13 @@ def MPC_RfFieldOffDetected() -> bool:
     return field.value > 0
 
 
-def MPC_WaitTypeAActiveState(atqa: bytes, uid: bytes,
-                             sak: Union[bytes, int],
-                             timeout: float) -> None:
+def MPC_WaitTypeAActiveState(
+        atqa: bytes,
+        uid: bytes,
+        sak: Union[bytes,
+                   int],
+        timeout: float
+        ) -> None:
     """Waits for Type A activation
 
     Parameters
@@ -254,8 +272,9 @@ def MPC_WaitTypeAActiveState(atqa: bytes, uid: bytes,
         c_uint32(timeout_ms)))
 
 
-def MPC_WaitAndGetFrame(timeout: float) \
-        -> Dict[str, Union[bytes, TechnologyType]]:
+def MPC_WaitAndGetFrame(
+        timeout: float
+        ) -> Dict[str, Union[bytes, TechnologyType]]:
     """Waits for an incoming frame
 
     Parameters
@@ -286,8 +305,9 @@ def MPC_WaitAndGetFrame(timeout: float) \
             'rx_type': TechnologyType(card_type.value)}
 
 
-def MPC_WaitAndGetFrameTypeA106ModeBit(timeout: float) \
-        -> Dict[str, Union[bytes, int]]:
+def MPC_WaitAndGetFrameTypeA106ModeBit(
+        timeout: float
+        ) -> Dict[str, Union[bytes, int]]:
     """Waits for a Type A 106kb/s incoming frame
 
     Parameters
@@ -319,7 +339,10 @@ def MPC_WaitAndGetFrameTypeA106ModeBit(timeout: float) \
             'rx_bits_number': rx_bits.value}
 
 
-def MPC_SendRawFrameType(card_type: TechnologyType, frame: bytes) -> None:
+def MPC_SendRawFrameType(
+        card_type: TechnologyType,
+        frame: bytes
+        ) -> None:
     """Transmits a frame
 
     Parameters
@@ -342,8 +365,10 @@ def MPC_SendRawFrameType(card_type: TechnologyType, frame: bytes) -> None:
         c_uint32(len(frame))))
 
 
-def MPC_SendRawFrameTypeWithCRC(card_type: TechnologyType,
-                                frame: bytes) -> None:
+def MPC_SendRawFrameTypeWithCRC(
+        card_type: TechnologyType,
+        frame: bytes
+        ) -> None:
     """Transmits a frame
 
     Parameters
@@ -366,8 +391,11 @@ def MPC_SendRawFrameTypeWithCRC(card_type: TechnologyType,
         c_uint32(len(frame))))
 
 
-def MPC_TransmitFrameA(frame: bytes, bits_number: Optional[int] = None,
-                       parity: bool = True) -> None:
+def MPC_TransmitFrameA(
+        frame: bytes,
+        bits_number: Optional[int] = None,
+        parity: bool = True
+        ) -> None:
     """Transmits a Type A 106kb/s frame
 
     Parameters
@@ -391,8 +419,10 @@ def MPC_TransmitFrameA(frame: bytes, bits_number: Optional[int] = None,
         c_int32(1) if parity else c_int32(0)))
 
 
-def MPS_SimSetDesyncPattern(t1_fc: Optional[float],
-                            t2_fc: Optional[float]) -> None:
+def MPS_SimSetDesyncPattern(
+        t1_fc: Optional[float],
+        t2_fc: Optional[float]
+        ) -> None:
     """Enables NFC Desync Pattern for following FeliCa frames
 
     Parameters
@@ -404,26 +434,28 @@ def MPS_SimSetDesyncPattern(t1_fc: Optional[float],
         t2 pattern duration in carrier periods
         (None to deactivate Desync Pattern)
     """
-    if t1_fc and t2_fc:
+    if t1_fc is not None and t2_fc is not None:
         t1_10fc = round(t1_fc * 1e1)
         _check_limits(c_uint32, t1_10fc, 't1_fc')
         t2_10fc = round(t2_fc * 1e1)
         _check_limits(c_uint32, t2_10fc, 't2_fc')
         CTS3Exception._check_error(_MPuLib.MPS_SimSetDesyncPattern(
             c_uint8(0),
-            c_uint8(1),
+            c_bool(True),
             c_uint32(t1_10fc),
             c_uint32(t2_10fc)))
     else:
         CTS3Exception._check_error(_MPuLib.MPS_SimSetDesyncPattern(
             c_uint8(0),
-            c_uint8(0),
+            c_bool(False),
             c_uint32(0),
             c_uint32(0)))
 
 
-def MPS_SimChangeDataRate(picc_datarate: DataRate,
-                          pcd_datarate: DataRate) -> None:
+def MPS_SimChangeDataRate(
+        picc_datarate: DataRate,
+        pcd_datarate: DataRate
+        ) -> None:
     """Selects PICC and PCD data rates
 
     Parameters
@@ -445,8 +477,10 @@ def MPS_SimChangeDataRate(picc_datarate: DataRate,
         c_uint16(pcd_datarate)))
 
 
-def MPC_SelectVICCDataRate(data_rate: VicinityDataRate,
-                           sub_carrier: VicinitySubCarrier) -> None:
+def MPC_SelectVICCDataRate(
+        data_rate: VicinityDataRate,
+        sub_carrier: VicinitySubCarrier
+        ) -> None:
     """Selects the VICC data rate
 
     Parameters
@@ -468,7 +502,9 @@ def MPC_SelectVICCDataRate(data_rate: VicinityDataRate,
         c_uint8(sub_carrier)))
 
 
-def MPS_SimVicinityEofMode(enabled: bool) -> None:
+def MPS_SimVicinityEofMode(
+        enabled: bool
+        ) -> None:
     """Enables Vicinity isolated EOF reception mode
 
     Parameters
@@ -481,7 +517,10 @@ def MPS_SimVicinityEofMode(enabled: bool) -> None:
         c_uint32(1) if enabled else c_uint32(0)))
 
 
-def MPS_SimSetFdt(fdt1_clk: int, fdt2_clk: int) -> None:
+def MPS_SimSetFdt(
+        fdt1_clk: int,
+        fdt2_clk: int
+        ) -> None:
     """Selects the FDT
 
     Parameters
@@ -517,7 +556,9 @@ class IqlmMode(IntEnum):
     IQLM_MODE_SETUP = 1
 
 
-def MPC_IQLMStart(mode: IqlmMode = IqlmMode.IQLM_MODE_DYNAMIC) -> None:
+def MPC_IQLMStart(
+        mode: IqlmMode = IqlmMode.IQLM_MODE_DYNAMIC
+        ) -> None:
     """Starts IQ load modulation regulation
 
     Parameters
@@ -532,8 +573,9 @@ def MPC_IQLMStart(mode: IqlmMode = IqlmMode.IQLM_MODE_DYNAMIC) -> None:
         c_uint8(mode)))
 
 
-def MPC_IQLoadModulationStart(mode: IqlmMode = IqlmMode.IQLM_MODE_DYNAMIC) \
-        -> None:
+def MPC_IQLoadModulationStart(
+        mode: IqlmMode = IqlmMode.IQLM_MODE_DYNAMIC
+        ) -> None:
     """Starts IQ load modulation regulation
 
     Parameters
@@ -546,7 +588,9 @@ def MPC_IQLoadModulationStart(mode: IqlmMode = IqlmMode.IQLM_MODE_DYNAMIC) \
     return MPC_IQLMStart(mode)
 
 
-def MPC_IQLMSuspendControlLoop(suspend: bool) -> None:
+def MPC_IQLMSuspendControlLoop(
+        suspend: bool
+        ) -> None:
     """Suspends IQ load modulation regulation
 
     Parameters
@@ -556,11 +600,13 @@ def MPC_IQLMSuspendControlLoop(suspend: bool) -> None:
     """
     CTS3Exception._check_error(_MPuLib.MPC_IQLMSuspendControlLoop(
         c_uint8(0),
-        c_uint8(1) if suspend else c_uint8(0),
+        c_bool(suspend),
         c_uint32(0)))
 
 
-def MPC_IQLoadModulationSuspendControlLoop(suspend: bool) -> None:
+def MPC_IQLoadModulationSuspendControlLoop(
+        suspend: bool
+        ) -> None:
     """Suspends IQ load modulation regulation
 
     Parameters
@@ -587,7 +633,10 @@ def MPC_IQLoadModulationStop() -> None:
     return MPC_IQLMStop()
 
 
-def MPC_IQLMSetHR(amplitude: float, phase: float) -> None:
+def MPC_IQLMSetHR(
+        amplitude: float,
+        phase: float
+        ) -> None:
     """Sets loading effect
 
     Parameters
@@ -608,7 +657,10 @@ def MPC_IQLMSetHR(amplitude: float, phase: float) -> None:
         c_uint32(0)))
 
 
-def MPC_IQLoadModulationSetHR(amplitude: float, phase: float) -> None:
+def MPC_IQLoadModulationSetHR(
+        amplitude: float,
+        phase: float
+        ) -> None:
     """Sets loading effect
 
     Parameters
@@ -623,9 +675,13 @@ def MPC_IQLoadModulationSetHR(amplitude: float, phase: float) -> None:
     return MPC_IQLMSetHR(amplitude, phase)
 
 
-def MPC_IQLMSidebands(lower_amplitude: float, lower_phase: float,
-                      upper_amplitude: float, upper_phase: float,
-                      offset: float) -> None:
+def MPC_IQLMSidebands(
+        lower_amplitude: float,
+        lower_phase: float,
+        upper_amplitude: float,
+        upper_phase: float,
+        offset: float
+        ) -> None:
     """Sets side bands
 
     Parameters
@@ -660,9 +716,13 @@ def MPC_IQLMSidebands(lower_amplitude: float, lower_phase: float,
         c_int32(offset_mV)))
 
 
-def MPC_IQLoadModulationSidebands(lower_amplitude: float, lower_phase: float,
-                                  upper_amplitude: float, upper_phase: float,
-                                  offset: float) -> None:
+def MPC_IQLoadModulationSidebands(
+        lower_amplitude: float,
+        lower_phase: float,
+        upper_amplitude: float,
+        upper_phase: float,
+        offset: float
+        ) -> None:
     """Sets side bands
 
     Parameters
@@ -694,8 +754,11 @@ class IqlmParameter(IntEnum):
     CP_IQLM_MODULATION_INHIBIT = 7
 
 
-def MPC_IQLMChangeParameters(parameter: IqlmParameter,
-                             value: Union[float, bool]) -> None:
+def MPC_IQLMChangeParameters(
+        parameter: IqlmParameter,
+        value: Union[float,
+                     bool]
+        ) -> None:
     """Changes IQ load modulation regulation parameter
 
     Parameters
@@ -720,8 +783,11 @@ def MPC_IQLMChangeParameters(parameter: IqlmParameter,
         c_uint32(0)))
 
 
-def MPC_IQLoadModulationChangeParameters(parameter: IqlmParameter,
-                                         value: Union[float, bool]) -> None:
+def MPC_IQLoadModulationChangeParameters(
+        parameter: IqlmParameter,
+        value: Union[float,
+                     bool]
+        ) -> None:
     """Changes IQ load modulation regulation parameter
 
     Parameters
@@ -749,8 +815,11 @@ class IqlmCondition(IntEnum):
     IQLM_PHASE_DRIFT_CONDITION_B2 = 6
 
 
-def MPC_IQLMPhaseDrift(frequency_drift: float, condition: IqlmCondition,
-                       data_rate: DataRate) -> None:
+def MPC_IQLMPhaseDrift(
+        frequency_drift: float,
+        condition: IqlmCondition,
+        data_rate: DataRate
+        ) -> None:
     """Selects phase drift
 
     Parameters
@@ -776,9 +845,11 @@ def MPC_IQLMPhaseDrift(frequency_drift: float, condition: IqlmCondition,
         data_rate))
 
 
-def MPC_IQLoadModulationPhaseDrift(frequency_drift: float,
-                                   condition: IqlmCondition,
-                                   data_rate: DataRate) -> None:
+def MPC_IQLoadModulationPhaseDrift(
+        frequency_drift: float,
+        condition: IqlmCondition,
+        data_rate: DataRate
+        ) -> None:
     """Selects phase drift
 
     Parameters
@@ -823,8 +894,8 @@ def MPC_IQLMGetStatus() -> Dict[str, Union[IqlmPhaseStatus, float]]:
             'frequency': freq.value}
 
 
-def MPC_IQLoadModulationGetStatus() \
-        -> Dict[str, Union[IqlmPhaseStatus, float]]:
+def MPC_IQLoadModulationGetStatus(
+        ) -> Dict[str, Union[IqlmPhaseStatus, float]]:
     """Gets IQ load modulation regulation status
 
     Returns
