@@ -1,8 +1,9 @@
 from enum import IntEnum, unique
+from ctypes import byref, create_string_buffer, sizeof, CFUNCTYPE
 from ctypes import c_uint8, c_int16, c_uint16, c_int32, c_uint32, c_uint64
-from ctypes import byref, create_string_buffer, sizeof, Structure
-from ctypes import c_char, c_char_p, c_float, c_double
-from typing import Optional, Dict, Union, List, cast
+from ctypes import Structure, c_bool, c_char, c_char_p, c_float, c_double
+from pathlib import Path
+from typing import Optional, Dict, Union, List, cast, Callable
 from . import _MPuLib, _MPuLib_variadic, _check_limits
 from .MPStatus import CTS3ErrorCode
 from .MPException import CTS3Exception
@@ -71,7 +72,10 @@ class DaqPoint():
         Value (in V, ° or dimensionless)
     """
 
-    def __init__(self, x: float, y: float):
+    def __init__(
+            self,
+            x: float,
+            y: float):
         """Inits DaqPoint
 
         Parameters
@@ -85,12 +89,15 @@ class DaqPoint():
         self.y = y
 
 
-def load_signals(file_path: str) -> List[List[DaqPoint]]:
+def load_signals(
+        file_path: Union[str,
+                         Path]
+        ) -> List[List[DaqPoint]]:
     """Loads DAQ signals from an acquisition file (single mode)
 
     Parameters
     ----------
-    file_path : str
+    file_path : str or Path
         Acquisition file
 
     Returns
@@ -114,91 +121,97 @@ def load_signals(file_path: str) -> List[List[DaqPoint]]:
         if footer.metadata_size:
             f.read(footer.metadata_size)
 
-        signal: List[DaqPoint] = []
-        date = start_date
-        if data_width == sizeof(c_int16):
-            SOURCE_PHASE = 6
-            SOURCE_VDC = 5
-            if channels == 1:
-                if header.source == SOURCE_PHASE:
-                    # Phase
-                    for y in iter_unpack('<h', file_content):
-                        value = float('nan') if y[0] > 8192 else \
-                                180.0 * cast(int, y[0]) / 8192.0
-                        signal.append(DaqPoint(date, value))
-                        date += 1.0 / sampling
-                elif header.source == SOURCE_VDC:
-                    # Vdc
+    signal: List[DaqPoint] = []
+    date = start_date
+    if data_width == sizeof(c_int16):
+        SOURCE_TXRX = 1
+        SOURCE_PHASE = 6
+        SOURCE_VDC = 5
+        if channels == 1:
+            if header.source == SOURCE_PHASE:
+                # Phase
+                for y in iter_unpack('<h', file_content):
+                    value = (float('nan') if y[0] > 8192
+                             else 180.0 * cast(int, y[0]) / 8192.0)
+                    signal.append(DaqPoint(date, value))
+                    date += 1.0 / sampling
+            elif header.source == SOURCE_VDC:
+                # Vdc
+                offset = cast(float, header.ch1.offset)
+                slope = cast(float, header.ch1.slope)
+                quadratic = cast(float, header.ch1.rms_noise)
+                cubic = cast(float, header.ch1.demod_noise)
+                for y in iter_unpack('<h', file_content):
+                    value = (offset + slope * cast(int, y[0]) +
+                             quadratic * cast(int, y[0]) ** 2 +
+                             cubic * cast(int, y[0]) ** 3) / 1e3
+                    signal.append(DaqPoint(date, value))
+                    date += 1.0 / sampling
+            else:
+                # Modulated signal
+                if header.ch1.config & 1:
                     offset = cast(float, header.ch1.offset)
                     slope = cast(float, header.ch1.slope)
-                    quadratic = cast(float, header.ch1.rms_noise)
-                    cubic = cast(float, header.ch1.demod_noise)
-                    for y in iter_unpack('<h', file_content):
-                        value = offset + slope * cast(int, y[0]) + \
-                                quadratic * cast(int, y[0]) ** 2 + \
-                                cubic * cast(int, y[0]) ** 3
-                        signal.append(DaqPoint(date, value))
-                        date += 1.0 / sampling
                 else:
-                    # Modulated signal
-                    if header.ch1.config & 1:
-                        offset = cast(float, header.ch1.offset)
-                        slope = cast(float, header.ch1.slope)
-                    else:
-                        offset = cast(float, header.ch2.offset)
-                        slope = cast(float, header.ch2.slope)
-                    for y in iter_unpack('<h', file_content):
-                        value = slope * (cast(int, y[0]) + offset)
-                        signal.append(DaqPoint(date, value))
-                        date += 1.0 / sampling
-                return [signal]
-
-            else:
-                # CH1 and CH2 data interleaved
-                offset_1 = cast(float, header.ch1.offset)
-                slope_1 = cast(float, header.ch1.slope)
-                offset_2 = cast(float, header.ch2.offset)
-                slope_2 = cast(float, header.ch2.slope)
-
-                signal_1: List[DaqPoint] = []
-                signal_2: List[DaqPoint] = []
-                date = start_date
-                toggle = True
+                    offset = cast(float, header.ch2.offset)
+                    slope = cast(float, header.ch2.slope)
+                if header.source != SOURCE_TXRX:
+                    slope /= 1e3
                 for y in iter_unpack('<h', file_content):
-                    if toggle:
-                        value = slope_1 * (cast(int, y[0]) + offset_1)
-                        signal_1.append(DaqPoint(date, value))
-                    else:
-                        value = slope_2 * (cast(int, y[0]) + offset_2)
-                        signal_2.append(DaqPoint(date, value))
-                    toggle = not toggle
+                    value = slope * (cast(int, y[0]) + offset)
+                    signal.append(DaqPoint(date, value))
                     date += 1.0 / sampling
-                return [signal_1, signal_2]
-
-        elif data_width == sizeof(c_uint32):
-            # Demodulated signal
-            if header.ch1.config & 1:
-                slope = cast(float, header.ch1.slope)
-                noise = cast(float, header.ch1.demod_noise)
-            else:
-                slope = cast(float, header.ch2.slope)
-                noise = cast(float, header.ch2.demod_noise)
-            slope *= cast(float, header.normalization)
-            for y in iter_unpack('<L', file_content):
-                value = slope * sqrt(y[0] - noise) if y[0] > noise else 0.0
-                signal.append(DaqPoint(date, value))
-                date += 1.0 / sampling
             return [signal]
 
-    return [[]]
+        else:
+            # CH1 and CH2 data interleaved
+            offset_1 = cast(float, header.ch1.offset)
+            slope_1 = cast(float, header.ch1.slope) / 1e3
+            offset_2 = cast(float, header.ch2.offset)
+            slope_2 = cast(float, header.ch2.slope) / 1e3
+
+            signal_1: List[DaqPoint] = []
+            signal_2: List[DaqPoint] = []
+            date = start_date
+            toggle = True
+            for y in iter_unpack('<h', file_content):
+                if toggle:
+                    value = slope_1 * (cast(int, y[0]) + offset_1)
+                    signal_1.append(DaqPoint(date, value))
+                else:
+                    value = slope_2 * (cast(int, y[0]) + offset_2)
+                    signal_2.append(DaqPoint(date, value))
+                    date += 1.0 / sampling
+                toggle = not toggle
+            return [signal_1, signal_2]
+
+    elif data_width == sizeof(c_uint32):
+        # Demodulated signal
+        if header.ch1.config & 1:
+            slope = cast(float, header.ch1.slope)
+            noise = cast(float, header.ch1.demod_noise)
+        else:
+            slope = cast(float, header.ch2.slope)
+            noise = cast(float, header.ch2.demod_noise)
+        slope *= cast(float, header.normalization) / 1e3
+        for y in iter_unpack('<L', file_content):
+            value = slope * sqrt(y[0] - noise) if y[0] > noise else 0.0
+            signal.append(DaqPoint(date, value))
+            date += 1.0 / sampling
+        return [signal]
+
+    return []
 
 
-def load_signal(file_path: str) -> List[List[float]]:
+def load_signal(
+        file_path: Union[str,
+                         Path]
+        ) -> List[List[float]]:
     """Loads DAQ signals from an acquisition file (single mode)
 
     Parameters
     ----------
-    file_path : str
+    file_path : str or Path
         Acquisition file
 
     Returns
@@ -208,75 +221,11 @@ def load_signal(file_path: str) -> List[List[float]]:
     """
     warn('load_signal replaced by load_signals',
          FutureWarning, 2)
-    with open(file_path, 'rb') as f:
-        header = _DaqHeader.from_buffer_copy(f.read(sizeof(_DaqHeader)))
-        if header.version < 2:
-            raise Exception(f'Unsupported DAQ file version ({header.version})')
-        data_width = int(header.bits_per_sample / 8)
-        data_length = cast(int, header.measurements_count)
-        channels = cast(int, header.channels)
-        file_content = f.read(channels * data_length * data_width)
-        footer = _DaqFooter.from_buffer_copy(f.read(sizeof(_DaqFooter)))
-        if footer.metadata_size:
-            f.read(footer.metadata_size)
-
-        if data_width == sizeof(c_int16):
-            SOURCE_PHASE = 6
-            SOURCE_VDC = 5
-            if channels == 1:
-                if header.source == SOURCE_PHASE:
-                    # Phase
-                    signal = [float('nan') if cast(int, y[0]) > 8192
-                              else 180.0 * cast(int, y[0]) / 8192.0
-                              for y in iter_unpack('<h', file_content)]
-                elif header.source == SOURCE_VDC:
-                    # Vdc
-                    offset = cast(float, header.ch1.offset)
-                    slope = cast(float, header.ch1.slope)
-                    quadratic = cast(float, header.ch1.rms_noise)
-                    cubic = cast(float, header.ch1.demod_noise)
-                    signal = [offset + slope * cast(int, y[0]) +
-                              quadratic * cast(int, y[0]) ** 2 +
-                              cubic * cast(int, y[0]) ** 3
-                              for y in iter_unpack('<h', file_content)]
-                else:
-                    # Modulated signal
-                    if header.ch1.config & 1:
-                        offset = cast(float, header.ch1.offset)
-                        slope = cast(float, header.ch1.slope)
-                    else:
-                        offset = cast(float, header.ch2.offset)
-                        slope = cast(float, header.ch2.slope)
-                    signal = [slope * (cast(int, y[0]) + offset)
-                              for y in iter_unpack('<h', file_content)]
-                return [signal]
-
-            else:
-                # CH1 and CH2 data interleaved
-                offset = cast(float, header.ch1.offset)
-                slope = cast(float, header.ch1.slope)
-                signal_1 = [slope * (cast(int, y[0]) + offset)
-                            for y in iter_unpack('<h', file_content)][0::2]
-                offset = cast(float, header.ch2.offset)
-                slope = cast(float, header.ch2.slope)
-                signal_2 = [slope * (cast(int, y[0]) + offset)
-                            for y in iter_unpack('<h', file_content)][1::2]
-                return [signal_1, signal_2]
-
-        elif data_width == sizeof(c_uint32):
-            # Demodulated signal
-            if header.ch1.config & 1:
-                slope = cast(float, header.ch1.slope)
-                noise = cast(float, header.ch1.demod_noise)
-            else:
-                slope = cast(float, header.ch2.slope)
-                noise = cast(float, header.ch2.demod_noise)
-            slope *= cast(float, header.normalization)
-            signal = [slope * sqrt(y[0] - noise) if y[0] > noise else 0.0
-                      for y in iter_unpack('<L', file_content)]
-            return [signal]
-
-    return [[]]
+    result = []
+    signals = load_signals(file_path)
+    for signal in signals:
+        result.append([pt.y for pt in signal])
+    return result
 
 
 @unique
@@ -303,9 +252,12 @@ class DaqNCTerm(IntEnum):
     NCT_OPEN = 1000000
 
 
-def Daq_SetChannel(channel: DaqChannel, enabled: bool,
-                   voltage_range: DaqRange,
-                   nc_term: DaqNCTerm = DaqNCTerm.NCT_50O) -> None:
+def Daq_SetChannel(
+        channel: DaqChannel,
+        enabled: bool,
+        voltage_range: DaqRange,
+        nc_term: DaqNCTerm = DaqNCTerm.NCT_50O
+        ) -> None:
     """Selects and configures a channel
 
     Parameters
@@ -321,31 +273,23 @@ def Daq_SetChannel(channel: DaqChannel, enabled: bool,
     """
     if not isinstance(channel, DaqChannel):
         raise TypeError('channel must be an instance of DaqChannel IntEnum')
-    if enabled:
-        if not isinstance(voltage_range, DaqRange):
-            raise TypeError('voltage_range must be an instance of '
-                            'DaqRange IntEnum')
-        if not isinstance(nc_term, DaqNCTerm):
-            raise TypeError('nc_term must be an instance of DaqNCTerm IntEnum')
-        CTS3Exception._check_error(_MPuLib.Daq_SetChannel(
-            c_uint8(channel),
-            c_uint8(1),
-            c_uint16(voltage_range),
-            c_uint32(0),
-            c_uint32(nc_term),
-            c_uint8(0)))
-    else:
-        CTS3Exception._check_error(_MPuLib.Daq_SetChannel(
-            c_uint8(channel),
-            c_uint8(0),
-            c_uint16(0),
-            c_uint32(0),
-            c_uint32(0),
-            c_uint8(0)))
+    if enabled and not isinstance(voltage_range, DaqRange):
+        raise TypeError('voltage_range must be an instance of '
+                        'DaqRange IntEnum')
+    if not isinstance(nc_term, DaqNCTerm):
+        raise TypeError('nc_term must be an instance of DaqNCTerm IntEnum')
+    CTS3Exception._check_error(_MPuLib.Daq_SetChannel(
+        c_uint8(channel),
+        c_bool(enabled),
+        c_uint16(voltage_range) if enabled else c_uint16(0),
+        c_uint32(0),
+        c_uint32(nc_term),
+        c_uint8(0)))
 
 
-def Daq_GetChannel(channel: DaqChannel) \
-        -> Dict[str, Union[bool, DaqRange, DaqNCTerm, None]]:
+def Daq_GetChannel(
+        channel: DaqChannel
+        ) -> Dict[str, Union[bool, DaqRange, DaqNCTerm, None]]:
     """Gets channel configuration
 
     Parameters
@@ -362,7 +306,7 @@ def Daq_GetChannel(channel: DaqChannel) \
     """
     if not isinstance(channel, DaqChannel):
         raise TypeError('channel must be an instance of DaqChannel IntEnum')
-    enabled = c_uint8()
+    enabled = c_bool()
     range_mV = c_uint16()
     impedance = c_uint32()
     term = c_uint32()
@@ -374,7 +318,7 @@ def Daq_GetChannel(channel: DaqChannel) \
         byref(impedance),
         byref(term),
         byref(rfu)))
-    if enabled.value > 0:
+    if enabled.value:
         return {'enabled': True,
                 'voltage_range': DaqRange(range_mV.value),
                 'nc_term': DaqNCTerm(term.value)}
@@ -391,8 +335,10 @@ class DaqSamplingClk(IntEnum):
     SCLK_EXT = 1
 
 
-def Daq_SetTimeBase(sampling_rate: DaqSamplingClk = DaqSamplingClk.SCLK_150MHZ,
-                    points_number: int = 0x10000000) -> None:
+def Daq_SetTimeBase(
+        sampling_rate: DaqSamplingClk = DaqSamplingClk.SCLK_150MHZ,
+        points_number: int = 0x10000000
+        ) -> None:
     """Configures the sampling rates and the number of points to acquire
     on the enabled channels
 
@@ -430,9 +376,12 @@ class DaqTrigDir(IntEnum):
     DIR_BOTH_EDGES = 2
 
 
-def Daq_SetTrigger(trigger_source: DaqTrigSource, level: float = 0,
-                   direction: DaqTrigDir = DaqTrigDir.DIR_BOTH_EDGES,
-                   delay: int = 0) -> None:
+def Daq_SetTrigger(
+        trigger_source: DaqTrigSource,
+        level: float = 0,
+        direction: DaqTrigDir = DaqTrigDir.DIR_BOTH_EDGES,
+        delay: int = 0
+        ) -> None:
     """Configures the trigger on enabled channels
 
     Parameters
@@ -483,11 +432,13 @@ class DaqDataFormat(IntEnum):
     FORMAT_RAW_16BITS = 0
 
 
-def Daq_StartStopAcq(acq_mode: DaqAcqMode,
-                     download_mode: DaqDownloadMode =
-                     DaqDownloadMode.MODE_DOWNLOAD,
-                     data_format: Optional[DaqDataFormat] = None,
-                     file_name: str = '') -> None:
+def Daq_StartStopAcq(
+        acq_mode: DaqAcqMode,
+        download_mode: DaqDownloadMode = DaqDownloadMode.MODE_DOWNLOAD,
+        data_format: Optional[DaqDataFormat] = None,
+        file_name: Union[str,
+                         Path] = ''
+        ) -> None:
     """Starts/Stops the acquisition
 
     Parameters
@@ -498,7 +449,7 @@ def Daq_StartStopAcq(acq_mode: DaqAcqMode,
         Download mode (only if acq_mode is MODE_SINGLE or MODE_RUN)
     data_format : DaqDataFormat, optional
         Not used
-    file_name : str, optional
+    file_name : str or Path, optional
         File name (only if acq_mode is MODE_SINGLE or MODE_RUN)
     """
     if not isinstance(acq_mode, DaqAcqMode):
@@ -513,11 +464,18 @@ def Daq_StartStopAcq(acq_mode: DaqAcqMode,
         func_pointer = _MPuLib.Daq_StartStopAcq
     else:
         func_pointer = _MPuLib_variadic.Daq_StartStopAcq
+    if isinstance(file_name, Path):
+        if str(file_name) != '.':
+            file = str(file_name).encode('ascii')
+        else:
+            file = ''.encode('ascii')
+    else:
+        file = file_name.encode('ascii')
     CTS3Exception._check_error(func_pointer(
         c_uint32(acq_mode),
         c_uint32(download_mode),
         c_uint32(0),
-        file_name.encode('ascii')))
+        file))
 
 
 @unique
@@ -564,8 +522,7 @@ def Daq_GetInfo() -> str:
         byref(version),
         byref(revision),
         byref(rfu)))
-    return str(year.value) + '.' + str(version.value) + '.' + \
-        str(revision.value)
+    return f'{year.value}.{version.value}.{revision.value}'
 
 
 @unique
@@ -575,7 +532,10 @@ class DaqFilter(IntEnum):
     VDC_FILTER = 3
 
 
-def Daq_SetFilter(filter: DaqFilter, enabled: bool) -> None:
+def Daq_SetFilter(
+        filter: DaqFilter,
+        enabled: bool
+        ) -> None:
     """Enables DAQ filter
 
     Parameters
@@ -589,13 +549,16 @@ def Daq_SetFilter(filter: DaqFilter, enabled: bool) -> None:
         raise TypeError('filter must be an instance of DaqFilter IntEnum')
     CTS3Exception._check_error(_MPuLib.Daq_SetFilter(
         c_uint32(filter),
-        c_uint8(1) if enabled else c_uint8(0)))
+        c_bool(enabled)))
 
 
 # region Probe Management
 
 
-def Daq_ProbeCompensation(channel: int, label: Optional[str]) -> None:
+def Daq_ProbeCompensation(
+        channel: int,
+        label: Optional[str]
+        ) -> None:
     """Performs active probe compensation
 
     Parameters
@@ -618,7 +581,10 @@ def Daq_ProbeCompensation(channel: int, label: Optional[str]) -> None:
             label.encode('ascii')))
 
 
-def Daq_LoadProbe(label: Optional[str], channel: int) -> None:
+def Daq_LoadProbe(
+        label: Optional[str],
+        channel: int
+        ) -> None:
     """Loads probe compensation information
 
     Parameters
@@ -650,11 +616,13 @@ def Daq_ListProbes() -> List[str]:
     cables_list = create_string_buffer(0xFFFF)
     CTS3Exception._check_error(_MPuLib.Daq_ListProbes(
         cables_list))
-    list_string = cables_list.value.decode('ascii')
+    list_string = cables_list.value.decode('ascii').strip()
     return list_string.split(';') if len(list_string) else []
 
 
-def Daq_DeleteProbe(label: str) -> None:
+def Daq_DeleteProbe(
+        label: str
+        ) -> None:
     """Removes probe compensation information from database
 
     Parameters
@@ -677,8 +645,9 @@ class DaqAutotestId(IntEnum):
     TEST_DAQ_REF = 300
 
 
-def MPS_DaqAutoTest(test_id: DaqAutotestId = DaqAutotestId.TEST_DAQ_ALL) \
-        -> List[List[str]]:
+def MPS_DaqAutoTest(
+        test_id: DaqAutotestId = DaqAutotestId.TEST_DAQ_ALL
+        ) -> List[List[str]]:
     """Performs DAQ self-test
 
     Parameters
@@ -696,11 +665,11 @@ def MPS_DaqAutoTest(test_id: DaqAutotestId = DaqAutotestId.TEST_DAQ_ALL) \
     result = c_char_p()
     ret = CTS3ErrorCode(_MPuLib.MPS_DaqAutoTest(
         c_uint32(test_id),
-        c_uint8(1),
+        c_bool(True),
         c_uint32(0),
         byref(result)))
-    if (ret >= CTS3ErrorCode.RET_FAIL and ret <= CTS3ErrorCode.RET_WARNING) \
-            or ret == CTS3ErrorCode.RET_OK:
+    if ((ret >= CTS3ErrorCode.RET_FAIL and ret <= CTS3ErrorCode.RET_WARNING)
+            or ret == CTS3ErrorCode.RET_OK):
         if result.value is None:
             return [['']]
         else:
@@ -710,3 +679,34 @@ def MPS_DaqAutoTest(test_id: DaqAutotestId = DaqAutotestId.TEST_DAQ_ALL) \
         raise CTS3Exception(ret)
 
 # endregion
+
+# region Firmware management
+
+
+def Daq_FlashFirmware(
+        partIndex: int,
+        call_back: Optional[Callable[[int], int]] = None
+        ) -> None:
+    """Flashes DAQ with a specific firmware
+
+    Parameters
+    ----------
+    partIndex : int
+        Index of the partition containing the DAQ firmware
+    call_back : Callable, optional
+        Update progress call back
+    """
+    _check_limits(c_uint8, partIndex, 'partIndex')
+    if call_back:
+        cmp_func = CFUNCTYPE(c_int32, c_int32)
+
+        CTS3Exception._check_error(_MPuLib.Daq_FlashFirmware(
+            c_uint8(partIndex),
+            cmp_func(call_back)))
+    else:
+        CTS3Exception._check_error(_MPuLib.Daq_FlashFirmware(
+            c_uint8(partIndex),
+            None))
+
+
+# endregion
