@@ -71,6 +71,7 @@ class CTS3ErrorCode(IntEnum):
     CRET_NO_MEASURE_PENDING = 0x00E1
     ERR_INVALID_IMPEDANCE_CALIBRATION_TABLE = 0x01F8
     ERR_NO_CABLE_INFORMATION = 0x01F9
+    ERR_NO_HEAD_INFORMATION = 0x01FA
     ERR_RESONANCE_FREQUENCY_MEASUREMENT = 0x01FB
     ERR_RF_FIELD_TOO_HIGH = 0x020B
     ERR_TRANSMIT_MEASURE_TO_FILE_FAILED = 0x0213
@@ -83,6 +84,12 @@ class CTS3ErrorCode(IntEnum):
     RET_DAQ_CHANNEL_NOT_SET = 0x0E13
     RET_DAQ_OVERVOLTAGE = 0x0E14
 
+    """
+    WLC error codes
+    """
+    RET_WLC_STOP_REQUEST = 0x0400
+    RET_WLC_IMPEDANCE_CHANGE = 0x0401
+
     """
     Protocol Analyzer error codes
     """
