@@ -1,5 +1,6 @@
 from ctypes import c_uint8, c_uint16, c_int32, c_uint32, c_double, byref
 from ctypes import c_void_p, POINTER, create_string_buffer, cast as c_cast
+from pathlib import Path
 from typing import List, Optional, Dict, Union, overload
 from enum import IntEnum, IntFlag, unique
 from . import _MPuLib, _check_limits
@@ -16,8 +17,10 @@ class VdcRange(IntEnum):
     VDC_RANGE_12V = 1
 
 
-def MPC_GetVDCIn(duration: float,
-                 voltmeter_range: VdcRange = VdcRange.VDC_RANGE_24V) -> float:
+def MPC_GetVDCIn(
+        duration: float,
+        voltmeter_range: VdcRange = VdcRange.VDC_RANGE_24V
+        ) -> float:
     """Performs a maximum voltage measurement on AUX 1 or VDC IN connector
 
     Parameters
@@ -46,8 +49,11 @@ def MPC_GetVDCIn(duration: float,
     return vdc.value / 1e3
 
 
-def MPC_GetVOV(integration_time: float, timeout: float,
-               voltmeter_range: VdcRange = VdcRange.VDC_RANGE_24V) -> float:
+def MPC_GetVOV(
+        integration_time: float,
+        timeout: float,
+        voltmeter_range: VdcRange = VdcRange.VDC_RANGE_24V
+        ) -> float:
     """Performs an integrated voltage measurement on AUX 1 or VDC IN connector
 
     Parameters
@@ -100,9 +106,15 @@ class MeasureSource(IntEnum):
     MEAS_SOURCE_PHASE = 5
 
 
-def MPC_StartRFMeasure2(settings: MeasureTriggerSetting, source: MeasureSource,
-                        unit: NfcUnit, delay: float, duration: float,
-                        file_name: str = '') -> None:
+def MPC_StartRFMeasure2(
+        settings: MeasureTriggerSetting,
+        source: MeasureSource,
+        unit: NfcUnit,
+        delay: float,
+        duration: float,
+        file_name: Union[str,
+                         Path] = ''
+        ) -> None:
     """Triggers an RF signal acquisition
 
     Parameters
@@ -117,7 +129,7 @@ def MPC_StartRFMeasure2(settings: MeasureTriggerSetting, source: MeasureSource,
         Trigger delay
     duration : float
         Acquisition duration
-    file_name : str, optional
+    file_name : str or Path, optional
         File name (only if settings contains MEAS_TRIG_SETTING_DOWNLOAD)
     """
     if not isinstance(settings, MeasureTriggerSetting):
@@ -128,10 +140,17 @@ def MPC_StartRFMeasure2(settings: MeasureTriggerSetting, source: MeasureSource,
     if not isinstance(unit, NfcUnit):
         raise TypeError('unit must be an instance of NfcUnit IntEnum')
     # Unit auto-selection
-    computed_unit, [computed_delay, computed_duration] = \
-        _unit_autoselect(unit, [delay, duration])
+    computed_unit, [computed_delay, computed_duration] = (
+        _unit_autoselect(unit, [delay, duration]))
     _check_limits(c_int32, computed_delay, 'delay')
     _check_limits(c_uint32, computed_duration, 'duration')
+    if isinstance(file_name, Path):
+        if str(file_name) != '.':
+            file = str(file_name).encode('ascii')
+        else:
+            file = ''.encode('ascii')
+    else:
+        file = file_name.encode('ascii')
     CTS3Exception._check_error(_MPuLib.MPC_StartRFMeasure2(
         c_uint8(0),
         c_uint32(settings),
@@ -139,7 +158,7 @@ def MPC_StartRFMeasure2(settings: MeasureTriggerSetting, source: MeasureSource,
         c_uint32(computed_unit),
         c_int32(computed_delay),
         c_uint32(computed_duration),
-        file_name.encode('ascii')))
+        file))
 
 
 @unique
@@ -177,8 +196,9 @@ class MeasurementConnector(IntEnum):
     CONNECTOR_RES_FREQ = 2
 
 
-def MPC_SwitchResonanceFrequencyConnector(connector: MeasurementConnector) \
-        -> None:
+def MPC_SwitchResonanceFrequencyConnector(
+        connector: MeasurementConnector
+        ) -> None:
     """Changes the connector currently selected to perform a measurement
 
     Parameters
@@ -205,7 +225,9 @@ class VoltmeterRange(IntEnum):
     VOLTMETER_RANGE_10000 = 10000
 
 
-def MPC_SelectVoltmeterRange(voltmeter_range: VoltmeterRange) -> None:
+def MPC_SelectVoltmeterRange(
+        voltmeter_range: VoltmeterRange
+        ) -> None:
     """Selects the voltmeter range on ANALOG IN connector
 
     Parameters
@@ -245,11 +267,14 @@ class MeasurementType(IntEnum):
     SCINFC_MEASTYPE_VDC = 3
 
 
-def GetAnalyzedMeasureVoltmeterToFile(measurement_type: MeasurementType,
-                                      card_type: TechnologyType,
-                                      data_rate: DataRate,
-                                      path: Optional[str] = None) \
-        -> Dict[str, Union[float, bool, List[float]]]:
+def GetAnalyzedMeasureVoltmeterToFile(
+        measurement_type: MeasurementType,
+        card_type: TechnologyType,
+        data_rate: DataRate,
+        path: Union[str,
+                    Path,
+                    None] = None
+        ) -> Dict[str, Union[float, bool, List[float]]]:
     """Analyzes analog measurements started with MPC_StartRFMeasure2
     and stores the results in a waveform file
 
@@ -261,7 +286,7 @@ def GetAnalyzedMeasureVoltmeterToFile(measurement_type: MeasurementType,
         Technology type
     data_rate : DataRate
         Data rate in kb/s
-    path : str, optional
+    path : str or Path, optional
         Path to waveform file
 
     Returns
@@ -313,13 +338,20 @@ def GetAnalyzedMeasureVoltmeterToFile(measurement_type: MeasurementType,
     measurement_count = c_uint32()
     measurements = c_void_p()
     if path:
+        if isinstance(path, Path):
+            if str(path) != '.':
+                file = str(path).encode('ascii')
+            else:
+                file = ''.encode('ascii')
+        else:
+            file = path.encode('ascii')
         CTS3Exception._check_error(_MPuLib.GetAnalyzedMeasureVoltmeterToFile(
             c_uint8(0),
             c_uint32(measurement_type),
             c_uint32(card_type),
             c_uint32(data_rate),
             c_uint32(0),
-            path.encode('ascii'),
+            file,
             byref(measurement_count),
             byref(measurements)))
     else:
@@ -336,8 +368,8 @@ def GetAnalyzedMeasureVoltmeterToFile(measurement_type: MeasurementType,
         ptr = c_cast(measurements, POINTER(c_int32 * measurement_count.value))
         values = [i for i in ptr.contents]
         if measurement_type == MeasurementType.SCINFC_MEASTYPE_PCD_WAVEFORM:
-            if card_type == TechnologyType.TYPE_A and \
-                    data_rate == DataRate.DATARATE_106KB:
+            if (card_type == TechnologyType.TYPE_A and
+                    data_rate == DataRate.DATARATE_106KB):
                 t5 = []
                 for i in range(16, 16 + values[15]):
                     t5 += [values[i] / 1e9]
@@ -359,8 +391,8 @@ def GetAnalyzedMeasureVoltmeterToFile(measurement_type: MeasurementType,
                         't5': t5,
                         'modulation_index': values[16 + len(t5)] / 1e6,
                         'modulation_depth': values[17 + len(t5)] / 1e6}
-            elif card_type == TechnologyType.TYPE_A and \
-                    data_rate > DataRate.DATARATE_106KB:
+            elif (card_type == TechnologyType.TYPE_A and
+                    data_rate > DataRate.DATARATE_106KB):
                 return {'t1': values[0] / 1e9,
                         't5': values[1] / 1e9,
                         't6': values[2] / 1e9,
@@ -379,8 +411,8 @@ def GetAnalyzedMeasureVoltmeterToFile(measurement_type: MeasurementType,
                         'high_state_noise_floor': values[15] / 1e6,
                         'monotonic_falling_edge': values[16] > 0,
                         'monotonic_rising_edge': values[17] > 0}
-            elif card_type == TechnologyType.TYPE_B or \
-                    card_type == TechnologyType.TYPE_FELICA:
+            elif (card_type == TechnologyType.TYPE_B or
+                    card_type == TechnologyType.TYPE_FELICA):
                 return {'falling_time': values[0] / 1e9,
                         'rising_time': values[1] / 1e9,
                         'monotonic_falling_edge': values[2] > 0,
@@ -419,8 +451,8 @@ def GetAnalyzedMeasureVoltmeterToFile(measurement_type: MeasurementType,
                 return {}
         elif measurement_type == MeasurementType.SCINFC_MEASTYPE_PICC_LMA:
             return {'lma': values[0] / 1e6}
-        elif measurement_type == \
-                MeasurementType.SCINFC_MEASTYPE_PCD_FIELD_STRENGTH:
+        elif (measurement_type ==
+                MeasurementType.SCINFC_MEASTYPE_PCD_FIELD_STRENGTH):
             return {'field_strength': values[0] / 1e6}
         else:
             return {}
@@ -428,16 +460,18 @@ def GetAnalyzedMeasureVoltmeterToFile(measurement_type: MeasurementType,
         return {}
 
 
-def MPC_StoreCoeffAlignStandard(measure_type: MeasurementType,
-                                coefficient: float) -> None:
-    """Stores a measurement compensation ratio into dual antenna EEPROM
+def MPC_StoreCoeffAlignStandard(
+        measure_type: MeasurementType,
+        coefficient: float
+        ) -> None:
+    """Stores a measurement compensation factor into dual antenna EEPROM
 
     Parameters
     ----------
     measurement_type : MeasurementType
         Type of measurement to compensate
     coefficient : float
-        Compensation ratio to be applied to the measurement
+        Compensation factor to be applied to the measurement
     """
     if not isinstance(measure_type, MeasurementType):
         raise TypeError('measure_type must be an instance of '
@@ -466,13 +500,16 @@ def MPC_GetRFFrequency() -> int:
 
 
 @overload
-def MPC_GetRFFrequency(resolution: FrequencyResolution,
-                       timeout: float) -> int:
+def MPC_GetRFFrequency(
+        resolution: FrequencyResolution,
+        timeout: float
+        ) -> int:
     ...
 
 
-def MPC_GetRFFrequency(resolution=None,  # type: ignore[no-untyped-def]
-                       timeout=None):
+def MPC_GetRFFrequency(  # type: ignore[no-untyped-def]
+        resolution=None,
+        timeout=None):
     """Performs a carrier frequency measurement
 
     Parameters
@@ -503,7 +540,9 @@ def MPC_GetRFFrequency(resolution=None,  # type: ignore[no-untyped-def]
 # region Data rate measurement
 
 
-def MPC_GetDatarate(card_type: TechnologyType) -> int:
+def MPC_GetDatarate(
+        card_type: TechnologyType
+        ) -> int:
     """Measures the last received frame data rate
 
     Parameters
@@ -531,16 +570,18 @@ def MPC_GetDatarate(card_type: TechnologyType) -> int:
 # region Impedance measurement
 
 
-def MPC_ImpedanceSelfCompensation(connector: MeasurementConnector,
-                                  channel: int,
-                                  label: Optional[str]) -> None:
+def MPC_ImpedanceSelfCompensation(
+        connector: MeasurementConnector,
+        channel: int,
+        label: Optional[str]
+        ) -> None:
     """Performs cable impedance compensation
 
     Parameters
     ----------
     connector : MeasurementConnector
-        Measurement connector used to perform the cable impedance compensation
-    channel :
+        Connector used to perform the cable impedance compensation
+    channel : int
         DAQ SMA input channel used to perform the cable impedance compensation
     label : str
         Compensation identifier
@@ -561,7 +602,9 @@ def MPC_ImpedanceSelfCompensation(connector: MeasurementConnector,
             label.encode('ascii')))
 
 
-def MPC_ImpedanceLoadCable(label: Optional[str]) -> None:
+def MPC_ImpedanceLoadCable(
+        label: Optional[str]
+        ) -> None:
     """Loads cable compensation information
 
     Parameters
@@ -591,11 +634,13 @@ def MPC_ImpedanceListCables() -> List[str]:
     CTS3Exception._check_error(_MPuLib.MPC_ImpedanceListCables(
         c_uint8(0),
         cables_list))
-    list_string = cables_list.value.decode('ascii')
+    list_string = cables_list.value.decode('ascii').strip()
     return list_string.split(';') if len(list_string) else []
 
 
-def MPC_ImpedanceDeleteCable(label: str) -> None:
+def MPC_ImpedanceDeleteCable(
+        label: str
+        ) -> None:
     """Removes cable compensation information from database
 
     Parameters
@@ -608,14 +653,131 @@ def MPC_ImpedanceDeleteCable(label: str) -> None:
         label.encode('ascii')))
 
 
-def MPC_MeasureImpedance(use_cable: bool = True, average: int = 1) \
-        -> Dict[str, Union[float, complex]]:
+def MPC_ImpedanceAdapterCompensation(
+        label: str,
+        meas_load: complex,
+        meas_short: complex,
+        meas_open: complex,
+        ref_load: complex,
+        ref_short: complex = 0,
+        ref_open: complex = complex('inf')
+        ) -> None:
+    """Performs adapter impedance compensation
+
+    Parameters
+    ----------
+    label : str
+        Adapter identifier
+    meas_load : complex
+        Measured load condition complex impedance in Ω
+    meas_short : complex
+        Measured short condition complex impedance in Ω
+    meas_open : complex
+        Measured open condition complex impedance in Ω
+    ref_load : complex, optional
+        Reference load condition complex impedance in Ω
+    ref_short : complex, optional
+        Reference short condition complex impedance in Ω
+    ref_open : complex, optional
+        Reference open condition complex impedance in Ω
+    """
+    CTS3Exception._check_error(_MPuLib.MPC_ImpedanceAdapterCompensation(
+        label.encode('ascii'),
+        c_double(meas_load.real),
+        c_double(meas_load.imag),
+        c_double(meas_short.real),
+        c_double(meas_short.imag),
+        c_double(meas_open.real),
+        c_double(meas_open.imag),
+        c_double(ref_load.real),
+        c_double(ref_load.imag),
+        c_double(ref_short.real),
+        c_double(ref_short.imag),
+        c_double(ref_open.real),
+        c_double(ref_open.imag)))
+
+
+def MPC_ImpedanceLoadAdapter(
+        label: Optional[str]
+        ) -> None:
+    """Loads adapter compensation information
+
+    Parameters
+    ----------
+    label : str
+        Compensation identifier
+    """
+    if label is None:
+        CTS3Exception._check_error(_MPuLib.MPC_ImpedanceLoadAdapter(
+            None))
+    else:
+        CTS3Exception._check_error(_MPuLib.MPC_ImpedanceLoadAdapter(
+            label.encode('ascii')))
+
+
+def MPC_ImpedanceListAdapters() -> List[str]:
+    """Lists available adapter compensations information
+
+    Returns
+    -------
+    list(str)
+        Compensation identifiers list
+    """
+    adapters_list = create_string_buffer(0xFFFF)
+    CTS3Exception._check_error(_MPuLib.MPC_ImpedanceListAdapters(
+        adapters_list))
+    list_string = adapters_list.value.decode('ascii').strip()
+    return list_string.split(';') if len(list_string) else []
+
+
+def MPC_ImpedanceDeleteAdapter(
+        label: str
+        ) -> None:
+    """Removes adapter compensation information from database
+
+    Parameters
+    ----------
+    label : str
+        Compensation identifier
+    """
+    CTS3Exception._check_error(_MPuLib.MPC_ImpedanceDeleteAdapter(
+        label.encode('ascii')))
+
+
+@unique
+class ImpedanceConfiguration(IntEnum):
+    """Impedance measurement configuration"""
+    WITH_NO_CABLE = 0
+    WITH_CABLE = 1
+    WITH_CABLE_AND_HEAD = 2
+
+
+@overload
+def MPC_MeasureImpedance(
+        config: bool = True,
+        average: int = 1
+        ) -> Dict[str, Union[float, complex]]:
+    ...
+
+
+@overload
+def MPC_MeasureImpedance(
+        config: ImpedanceConfiguration = ImpedanceConfiguration.WITH_CABLE,
+        average: int = 1
+        ) -> Dict[str, Union[float, complex]]:
+    ...
+
+
+def MPC_MeasureImpedance(  # type: ignore[no-untyped-def]
+        config=ImpedanceConfiguration.WITH_CABLE,
+        average=1
+        ) -> Dict[str, Union[float, complex]]:
     """Performs an impedance measurement
 
     Parameters
     ----------
-    use_cable : bool, optional
-        True if impedance to measure is connected with a cable
+    config : ImpedanceConfiguration, optional
+        Configuration of impedance to measure
     average : int, optional
         Measurements number to average
 
@@ -629,6 +791,14 @@ def MPC_MeasureImpedance(use_cable: bool = True, average: int = 1) \
         'vcc' (float): Estimated voltage on the measured impedance in Vpp
         'icc' (float): Estimated current on the measured impedance in App
     """
+    if isinstance(config, bool):
+        warn("deprecated 'config' parameter type", FutureWarning, 2)
+        configuration = c_uint8(1) if config else c_uint8(0)
+    elif isinstance(config, ImpedanceConfiguration):
+        configuration = c_uint8(config)
+    else:
+        raise TypeError('config must be an instance of '
+                        'ImpedanceConfiguration IntEnum')
     _check_limits(c_uint32, average, 'average')
     real_part = c_double()
     imaginary_part = c_double()
@@ -639,7 +809,7 @@ def MPC_MeasureImpedance(use_cable: bool = True, average: int = 1) \
     icc = c_double()
     CTS3Exception._check_error(_MPuLib.MPC_MeasureImpedance(
         c_uint8(0),
-        c_uint8(1) if use_cable else c_uint8(0),
+        configuration,
         c_uint32(average),
         byref(real_part),
         byref(imaginary_part),
@@ -667,13 +837,14 @@ class ResonanceMethod(IntEnum):
     RESONANCE_NFC = 2
 
 
-def MPC_ResonanceFrequency(method: ResonanceMethod,
-                           power_dbm: float,
-                           step: float,
-                           freq_min: float,
-                           freq_max: float,
-                           average: int = 1) \
-        -> Dict[str, Union[int, float]]:
+def MPC_ResonanceFrequency(
+        method: ResonanceMethod,
+        power_dbm: float,
+        step: float,
+        freq_min: float,
+        freq_max: float,
+        average: int = 1
+        ) -> Dict[str, Union[int, float]]:
     """Performs a resonance frequency measurement
 
     Parameters
@@ -732,8 +903,9 @@ class ResFreqMeasureType(IntEnum):
     RF_IMAGINARY_PART = 2
 
 
-def MPC_GetMeasureResFreq(measure_type: ResFreqMeasureType =
-                          ResFreqMeasureType.RF_REAL_PART) -> List[float]:
+def MPC_GetMeasureResFreq(
+        measure_type: ResFreqMeasureType = ResFreqMeasureType.RF_REAL_PART
+        ) -> List[float]:
     """Reads resonance frequency measured values
 
     Parameters
@@ -767,11 +939,13 @@ def MPC_GetMeasureResFreq(measure_type: ResFreqMeasureType =
 
 # region S11 measurement
 
-def MPC_S11StartMeasurement(frequency_min: float,
-                            frequency_max: float,
-                            step: float,
-                            power_dbm: float,
-                            average: int = 1) -> None:
+def MPC_S11StartMeasurement(
+        frequency_min: float,
+        frequency_max: float,
+        step: float,
+        power_dbm: float,
+        average: int = 1
+        ) -> None:
     """Starts as S11 measurement
 
     Parameters
@@ -813,8 +987,9 @@ class S11MeasureType(IntEnum):
     S11_IMAGINARY_PART = 2
 
 
-def MPC_GetMeasureS11(measure_type: S11MeasureType =
-                      S11MeasureType.S11_RETURN_LOSS) -> List[float]:
+def MPC_GetMeasureS11(
+        measure_type: S11MeasureType = S11MeasureType.S11_RETURN_LOSS
+        ) -> List[float]:
     """Reads S11 measured values
 
     Parameters
@@ -844,7 +1019,9 @@ def MPC_GetMeasureS11(measure_type: S11MeasureType =
         return []
 
 
-def MPC_GetS11(frequency: float = 0.0) -> Dict[str, Union[float, complex]]:
+def MPC_GetS11(
+        frequency: float = 0.0
+        ) -> Dict[str, Union[float, complex]]:
     """Gets the S11 value at a specific frequency
 
     Parameters
@@ -888,8 +1065,8 @@ def MPC_GetS11(frequency: float = 0.0) -> Dict[str, Union[float, complex]]:
         byref(real_at_frequency),
         byref(imaginary_at_frequency),
         byref(module_at_frequency))
-    if ret == CTS3ErrorCode.ERR_RESONANCE_FREQUENCY_MEASUREMENT.value and \
-            frequency > 0.0:
+    if (ret == CTS3ErrorCode.ERR_RESONANCE_FREQUENCY_MEASUREMENT.value and
+            frequency > 0.0):
         return {'dbm_at_frequency': dbm_at_frequency.value,
                 'impedance_at_frequency': complex(real_at_frequency.value,
                                                   imaginary_at_frequency.value)
@@ -922,8 +1099,9 @@ class CalibrationCoil(IntEnum):
     RFFIELD_ASSEMBLY_2 = 2
 
 
-def MPC_GetRFField(coil: CalibrationCoil =
-                   CalibrationCoil.RFFIELD_ASSEMBLY_1) -> float:
+def MPC_GetRFField(
+        coil: CalibrationCoil = CalibrationCoil.RFFIELD_ASSEMBLY_1
+        ) -> float:
     """Measures the field strength on ANALOG IN connector
 
     Parameters
