@@ -1,7 +1,6 @@
 import sys
 from platform import processor, architecture
-from os import sep
-from os.path import dirname, abspath, isfile, join
+from pathlib import Path
 from time import sleep
 from atexit import register
 from subprocess import Popen, PIPE, DEVNULL
@@ -13,8 +12,8 @@ from enum import IntEnum, IntFlag, unique
 from xml.dom.minidom import parseString
 from datetime import datetime
 from ctypes import c_char, c_char_p, c_uint8, c_int16, c_uint16
-from ctypes import c_int32, c_uint32, c_double, sizeof
-from ctypes import byref, create_string_buffer
+from ctypes import c_bool, c_int32, c_uint32, c_double
+from ctypes import sizeof, byref, create_string_buffer
 from ctypes import CDLL, Structure, CFUNCTYPE
 from .MPStatus import CTS3ErrorCode
 
@@ -26,9 +25,9 @@ if sys.platform == 'win32':
     from ctypes import WinDLL
 
 
-__version__ = '22.0.0'
+__version__ = '22.1.0'
 __author__ = 'NI'
-__copyright__ = 'Copyright 2022, NI'
+__copyright__ = f'Copyright 20{__version__[:2]}, NI'
 __license__ = 'MIT'
 
 
@@ -37,47 +36,47 @@ class MpDll(CDLL):
 
 
 # Load MPuLib from local path
-_lib_sys: Optional[str] = None
+_lib_sys: Optional[Path] = None
 _lib_name: Optional[str] = None
-_lib_path: str = join(dirname(abspath(__file__)), '.lib')
+_lib_path = Path(__file__).resolve().parent.joinpath('.lib')
 if sys.platform == 'win32':
     class MpWinDll(WinDLL):
         _func_restype_ = c_int16  # type: ignore[assignment]
 
-    _lib_path = join(_lib_path, 'Windows')
+    _lib_path = _lib_path.joinpath('Windows')
     if architecture()[0] == '32bit':
         _lib_name = 'MPuLib-win32.dll'
     else:
         _lib_name = 'MPuLib-win64.dll'
 elif sys.platform == 'cygwin':
-    _lib_path = join(_lib_path, 'Windows')
+    _lib_path = _lib_path.joinpath('Windows')
     if architecture()[0] == '64bit':
         _lib_name = 'MPuLib-win64.dll'
     else:
         raise NotImplementedError('Unsupported cygwin architecture')
 else:
     if sys.platform == 'darwin':
-        _lib_path = join(_lib_path, 'macOS')
+        _lib_path = _lib_path.joinpath('macOS')
         _lib_name = 'libMPuLib.dylib'
     elif sys.platform == 'linux':
         if processor().startswith('armv7'):
             # CTS3 embedded library
-            _lib_path = join(_lib_path, 'Arm')
+            _lib_path = _lib_path.joinpath('Arm')
         else:
-            _lib_path = join(_lib_path, 'Linux')
+            _lib_path = _lib_path.joinpath('Linux')
             if architecture()[0] == '32bit':
-                _lib_path = join(_lib_path, 'x86')
+                _lib_path = _lib_path.joinpath('x86')
             else:
-                _lib_path = join(_lib_path, 'x64')
+                _lib_path = _lib_path.joinpath('x64')
         _lib_name = 'libMPuLib.so'
     else:
         raise NotImplementedError(f'Unsupported platform: {sys.platform}')
-    _lib_sys = join(sep, 'usr', 'lib', _lib_name)
+    _lib_sys = Path('/usr', 'lib', _lib_name)
 
 # Locate library
-_lib_path = join(_lib_path, _lib_name)
-if not isfile(_lib_path):
-    if _lib_sys and isfile(_lib_sys):
+_lib_path = _lib_path.joinpath(_lib_name)
+if not _lib_path.is_file():
+    if _lib_sys and _lib_sys.is_file():
         # Use library located in system path
         _lib_path = _lib_sys
     else:
@@ -85,13 +84,13 @@ if not isfile(_lib_path):
 
 # Load library
 if sys.platform == 'win32':
-    _MPuLib: MpWinDll = MpWinDll(_lib_path)
+    _MPuLib: MpWinDll = MpWinDll(str(_lib_path))
 else:
-    _MPuLib: MpDll = MpDll(_lib_path)
+    _MPuLib: MpDll = MpDll(str(_lib_path))
 _MPuLib_variadic: Optional[MpDll] = None
 if sys.platform == 'win32' and architecture()[0] == '32bit':
     # Load library for variadic functions
-    _MPuLib_variadic = MpDll(_lib_path)
+    _MPuLib_variadic = MpDll(str(_lib_path))
 
 
 class _FirmwareLog(Thread):
@@ -109,7 +108,10 @@ class _FirmwareLog(Thread):
         Log redirection subprocess
     """
 
-    def __init__(self, host: str, started: Event):
+    def __init__(
+            self,
+            host: str,
+            started: Event):
         """Inits _FirmwareLog Thread
 
         Parameters
@@ -128,7 +130,9 @@ class _FirmwareLog(Thread):
         self.running = False
         Thread.__init__(self, daemon=True)
 
-    def run(self) -> None:
+    def run(
+            self
+            ) -> None:
         """Starts log redirection"""
         # Follow log and read last entry
         log_cmd = 'journalctl --unit=tgapp --follow --lines=1 --output=cat'
@@ -145,9 +149,9 @@ class _FirmwareLog(Thread):
                                      stderr=DEVNULL)
                 else:
                     # Running from remote environment, open SSH connection
-                    ssh_cmd = 'ssh -Tnq -l default -o ' + \
-                              'StrictHostKeyChecking=no ' + self.host
-                    self.log = Popen(split(ssh_cmd + ' ' + log_cmd),
+                    ssh_cmd = ('ssh -Tnq -l default -o '
+                               f'StrictHostKeyChecking=no {self.host}')
+                    self.log = Popen(split(f'{ssh_cmd} {log_cmd}'),
                                      bufsize=1,
                                      universal_newlines=True,
                                      encoding='ascii',
@@ -167,7 +171,9 @@ class _FirmwareLog(Thread):
         except Exception:
             self.running = False
 
-    def stop(self) -> None:
+    def stop(
+            self
+            ) -> None:
         """Stops log redirection"""
         if self.running:
             self.running = False
@@ -176,9 +182,15 @@ class _FirmwareLog(Thread):
             Thread.join(self)
 
 
-def _check_limits(c_type: Union[Type[c_uint8], Type[c_uint16], Type[c_uint32],
-                                Type[c_int16], Type[c_int32]],
-                  int_value: int, var_name: str) -> None:
+def _check_limits(
+        c_type: Union[Type[c_uint8],
+                      Type[c_uint16],
+                      Type[c_uint32],
+                      Type[c_int16],
+                      Type[c_int32]],
+        int_value: int,
+        var_name: str
+        ) -> None:
     """Checks if integer value is within C type integer range
 
     Parameters
@@ -195,13 +207,15 @@ def _check_limits(c_type: Union[Type[c_uint8], Type[c_uint16], Type[c_uint32],
     signed_limit = 2 ** (bit_size - 1)
     if signed:
         if int_value < -signed_limit or int_value > signed_limit - 1:
-            raise OverflowError(var_name + ' is out of range')
+            raise OverflowError(f'{var_name} is out of range')
     else:
         if int_value < 0 or int_value > 2 * signed_limit - 1:
-            raise OverflowError(var_name + ' is out of range')
+            raise OverflowError(f'{var_name} is out of range')
 
 
-def GetErrorMessageFromCode(error_code: int) -> str:
+def GetErrorMessageFromCode(
+        error_code: int
+        ) -> str:
     """Converts an error code into an error message
 
     Parameters
@@ -220,10 +234,12 @@ def GetErrorMessageFromCode(error_code: int) -> str:
         c_uint16(error_code))).decode('ascii')
     if len(message) > 0:
         return message
-    return f'Unknown error code {error_code}'
+    return f'Unknown error code 0x{error_code:04X}'
 
 
-def GetMifareErrorMessageFromCode(error_code: int) -> str:
+def GetMifareErrorMessageFromCode(
+        error_code: int
+        ) -> str:
     """Converts a MIFARE error code into an error message
 
     Parameters
@@ -242,7 +258,7 @@ def GetMifareErrorMessageFromCode(error_code: int) -> str:
         c_int32(error_code))).decode('ascii')
     if len(message) > 0:
         return message
-    return f'Unknown error code {error_code}'
+    return f'Unknown error code 0x{error_code:02X}'
 
 
 from .MPException import CTS3Exception  # noqa: E402
@@ -260,7 +276,8 @@ def _get_connection_string() -> str:
         Connection string
     """
     host_name = create_string_buffer(128)
-    ret = CTS3ErrorCode(_MPuLib.GetConnectionString(host_name))
+    ret = CTS3ErrorCode(_MPuLib.GetConnectionString(
+        host_name))
     if ret == CTS3ErrorCode.RET_OK:
         return host_name.value.decode('ascii')
     return ''
@@ -316,9 +333,12 @@ class ResourceBlockingMode(IntEnum):
     OVERRIDE = 3
 
 
-def MPOS_OpenResource(resource_id: Union[int, ResourceType, None] = None,
-                      blocking_mode: ResourceBlockingMode =
-                      ResourceBlockingMode.NOT_BLOCKING) -> None:
+def MPOS_OpenResource(
+        resource_id: Union[int,
+                           ResourceType,
+                           None] = None,
+        blocking_mode: ResourceBlockingMode = ResourceBlockingMode.NOT_BLOCKING
+        ) -> None:
     """Opens a resource
 
     Parameters
@@ -337,7 +357,8 @@ def MPOS_OpenResource(resource_id: Union[int, ResourceType, None] = None,
             c_uint32(ResourceType.CTS3_DAQ_RESOURCE_ID),
             c_uint8(0),
             c_uint32(blocking_mode))
-        if ret_code != 27:  # For compatiblity with MP500
+        if (ret_code != 27 and  # For compatiblity with MP500
+                ret_code != CTS3ErrorCode.RET_COUPLER_NOT_DETECTED.value):
             CTS3Exception._check_error(ret_code)
         ret_code = _MPuLib.MPOS_OpenResource(
             c_uint32(MPOS_GetResourceID()),
@@ -355,8 +376,11 @@ def MPOS_OpenResource(resource_id: Union[int, ResourceType, None] = None,
             c_uint32(blocking_mode)))
 
 
-def MPOS_CloseResource(resource_id: Union[int, ResourceType, None] =
-                       None) -> None:
+def MPOS_CloseResource(
+        resource_id: Union[int,
+                           ResourceType,
+                           None] = None
+        ) -> None:
     """Closes a resource
 
     Parameters
@@ -369,39 +393,43 @@ def MPOS_CloseResource(resource_id: Union[int, ResourceType, None] =
         ret = CTS3ErrorCode(_MPuLib.MPOS_CloseResource(
             c_uint32(MPOS_GetResourceID()),
             c_uint8(0)))
-        if ret != CTS3ErrorCode.RET_OK and \
-                ret != CTS3ErrorCode.RET_RESOURCE_NOT_OPEN:
+        if (ret != CTS3ErrorCode.RET_OK and
+                ret != CTS3ErrorCode.RET_RESOURCE_NOT_OPEN):
             raise CTS3Exception(ret)
         ret = CTS3ErrorCode(_MPuLib.MPOS_CloseResource(
             c_uint32(ResourceType.CTS3_DAQ_RESOURCE_ID),
             c_uint8(0)))
-        if ret != CTS3ErrorCode.RET_OK and \
-                ret != CTS3ErrorCode.RET_RESOURCE_INVALID_ID and \
-                ret != CTS3ErrorCode.RET_RESOURCE_NOT_OPEN:
+        if (ret != CTS3ErrorCode.RET_OK and
+                ret != CTS3ErrorCode.RET_RESOURCE_INVALID_ID and
+                ret != CTS3ErrorCode.RET_RESOURCE_NOT_OPEN and
+                ret != CTS3ErrorCode.RET_COUPLER_NOT_DETECTED):
             raise CTS3Exception(ret)
     else:
         _check_limits(c_uint32, resource_id, 'resource_id')
         ret = CTS3ErrorCode(_MPuLib.MPOS_CloseResource(
             c_uint32(resource_id),
             c_uint8(0)))
-        if ret != CTS3ErrorCode.RET_OK and \
-                ret != CTS3ErrorCode.RET_RESOURCE_NOT_OPEN:
+        if (ret != CTS3ErrorCode.RET_OK and
+                ret != CTS3ErrorCode.RET_RESOURCE_NOT_OPEN):
             raise CTS3Exception(ret)
 
 
-def MPOS_GetResourceID() -> int:
+def MPOS_GetResourceID() -> Union[int, ResourceType]:
     """Gets the resource identifier
 
     Returns
     -------
-    int
+    int or ResourceType
         Resource identifier
     """
     resource_id = c_uint32()
     CTS3Exception._check_error(_MPuLib.MPOS_GetResourceID(
         c_uint8(0),
         byref(resource_id)))
-    return resource_id.value
+    try:
+        return ResourceType(resource_id.value)
+    except ValueError:
+        return resource_id.value
 
 # endregion
 
@@ -461,9 +489,13 @@ class EEConfig(IntEnum):
     EEC_AUTO_BOOT = 1
     EEC_DEBUG_PORT = 4
     EEC_TELNET_NEGO = 5
+    EEC_WINUSB_DRIVER = 6
 
 
-def MPS_EESetConfig(config: EEConfig, value: bool) -> None:
+def MPS_EESetConfig(
+        config: EEConfig,
+        value: bool
+        ) -> None:
     """Sets product configuration
 
     Parameters
@@ -481,7 +513,9 @@ def MPS_EESetConfig(config: EEConfig, value: bool) -> None:
         c_uint32(1) if value else c_uint32(0)))
 
 
-def MPS_EEGetConfig(config: EEConfig) -> bool:
+def MPS_EEGetConfig(
+        config: EEConfig
+        ) -> bool:
     """Gets product configuration
 
     Parameters
@@ -504,7 +538,9 @@ def MPS_EEGetConfig(config: EEConfig) -> bool:
     return value.value > 0
 
 
-def MPS_SelectActivePartition(partition: int) -> None:
+def MPS_SelectActivePartition(
+        partition: int
+        ) -> None:
     """Selects the partition to activate on the next reboot
 
     Parameters
@@ -531,7 +567,9 @@ def MPS_GetActivePartition() -> int:
     return partition.value
 
 
-def MPS_ListVersions(partition: int) -> Dict[str, Union[str, int]]:
+def MPS_ListVersions(
+        partition: int
+        ) -> Dict[str, Union[str, int]]:
     """Reads the firmware version present on a partition
 
     Parameters
@@ -571,14 +609,17 @@ def MPS_ListVersions(partition: int) -> Dict[str, Union[str, int]]:
         return {'active_partition': current_partition.value}
 
 
-def UpdateFirmware(path: str, partIndex: int,
-                   call_back: Optional[Callable[[int], int]] =
-                   None) -> None:
+def UpdateFirmware(
+        path: Union[str,
+                    Path],
+        partIndex: int,
+        call_back: Optional[Callable[[int], int]] = None
+        ) -> None:
     """Updates the CTS3 firmware
 
     Parameters
     ----------
-    path : str
+    path : str or Path
         Firmware package path
     partIndex : int
         Index of the partition to update
@@ -586,30 +627,57 @@ def UpdateFirmware(path: str, partIndex: int,
         Update progress call back
     """
     _check_limits(c_uint8, partIndex, 'partIndex')
+    if isinstance(path, Path):
+        file = str(path).encode('ascii')
+    else:
+        file = path.encode('ascii')
     if call_back:
         cmp_func = CFUNCTYPE(c_int32, c_int32)
 
         CTS3Exception._check_error(_MPuLib.UpdateFirmware(
-            path.encode('ascii'),
+            file,
             c_uint8(partIndex),
             cmp_func(call_back)))
     else:
         CTS3Exception._check_error(_MPuLib.UpdateFirmware(
-            path.encode('ascii'),
+            file,
             c_uint8(partIndex),
             None))
 
 
-def ApplyLicenseUpdateFile(path: str) -> None:
+def GetLastFirmwareUpdateErrorMessageEx() -> str:
+    """Gets the firmware update logs
+
+    Returns
+    -------
+    str
+        Update process logs
+    """
+    max_size = 2 * 1024 * 1024
+    message = create_string_buffer(max_size)
+    CTS3Exception._check_error(_MPuLib.GetLastFirmwareUpdateErrorMessageEx(
+        message,
+        c_uint32(max_size)))
+    return message.value.decode('ascii').strip()
+
+
+def ApplyLicenseUpdateFile(
+        path: Union[str,
+                    Path]
+        ) -> None:
     """Applies a license update file
 
     Parameters
     ----------
-    path : str
+    path : str or Path
         License update file path
     """
+    if isinstance(path, Path):
+        file = str(path).encode('ascii')
+    else:
+        file = path.encode('ascii')
     CTS3Exception._check_error(_MPuLib.ApplyLicenseUpdateFile(
-        path.encode('ascii')))
+        file))
 
 
 @unique
@@ -622,8 +690,10 @@ class CpuAutotestId(IntEnum):
     TEST_CPU_LOAD = 4
 
 
-def MPS_CPUAutoTest(test_id: CpuAutotestId = CpuAutotestId.TEST_CPU_ALL,
-                    parameter: int = 0) -> List[List[str]]:
+def MPS_CPUAutoTest(
+        test_id: CpuAutotestId = CpuAutotestId.TEST_CPU_ALL,
+        parameter: int = 0
+        ) -> List[List[str]]:
     """Performs CPU self-test
 
     Parameters
@@ -643,9 +713,9 @@ def MPS_CPUAutoTest(test_id: CpuAutotestId = CpuAutotestId.TEST_CPU_ALL,
         raise TypeError('test_id must be an instance of CpuAutotestId IntEnum')
     _check_limits(c_uint32, parameter, 'parameter')
     restore_log = False
-    if test_id == CpuAutotestId.TEST_CPU_ALL or \
+    if (test_id == CpuAutotestId.TEST_CPU_ALL or
             (test_id == CpuAutotestId.TEST_FLASH and
-                (parameter & 0xF == 0 or parameter & 0xF == 6)):
+             (parameter & 0xF == 0 or parameter & 0xF == 6))):
         # Close 'default' user connection to allow user data partition analysis
         host = _get_connection_string()
         if len(host) > 0 and host in _logs_dict:
@@ -654,13 +724,13 @@ def MPS_CPUAutoTest(test_id: CpuAutotestId = CpuAutotestId.TEST_CPU_ALL,
     result = c_char_p()
     ret = CTS3ErrorCode(_MPuLib.MPS_CPUAutoTest(
         c_uint32(test_id),
-        c_uint8(1),
+        c_bool(True),
         c_uint32(parameter),
         byref(result)))
     if restore_log:
         _log_start()
-    if (ret >= CTS3ErrorCode.RET_FAIL and ret <= CTS3ErrorCode.RET_WARNING) \
-            or ret == CTS3ErrorCode.RET_OK:
+    if ((ret >= CTS3ErrorCode.RET_FAIL and ret <= CTS3ErrorCode.RET_WARNING)
+            or ret == CTS3ErrorCode.RET_OK):
         if result.value is None:
             return [['']]
         else:
@@ -670,7 +740,11 @@ def MPS_CPUAutoTest(test_id: CpuAutotestId = CpuAutotestId.TEST_CPU_ALL,
         raise CTS3Exception(ret)
 
 
-def MPS_ResetHard(resource_id: Union[int, ResourceType, None] = None) -> None:
+def MPS_ResetHard(
+        resource_id: Union[int,
+                           ResourceType,
+                           None] = None
+        ) -> None:
     """Resets application to its default state
 
     Parameters
@@ -708,9 +782,10 @@ def MPS_NetworkGetAddress() -> Dict[str, Union[IPv4Interface, IPv4Address]]:
             'gateway_address': IPv4Address(gateway_address.value)}
 
 
-def MPS_NetworkSetAddress(ip_interface: Optional[IPv4Interface],
-                          gateway_address: Optional[IPv4Address] = None) \
-                         -> None:
+def MPS_NetworkSetAddress(
+        ip_interface: Optional[IPv4Interface],
+        gateway_address: Optional[IPv4Address] = None
+        ) -> None:
     """Sets the network configuration
 
     Parameters
@@ -744,7 +819,9 @@ def MPS_NetworkSetAddress(ip_interface: Optional[IPv4Interface],
                 c_uint32(int(gateway_address))))
 
 
-def MPS_NetworkSetUsbAddress(ip_interface: IPv4Interface) -> None:
+def MPS_NetworkSetUsbAddress(
+        ip_interface: IPv4Interface
+        ) -> None:
     """Sets the USB network base address
 
     Parameters
@@ -767,7 +844,9 @@ class TemperatureSensor(IntEnum):
     DaqBoardSensor = 2
 
 
-def MPS_ProbeTemperature(sensor: TemperatureSensor) -> float:
+def MPS_ProbeTemperature(
+        sensor: TemperatureSensor
+        ) -> float:
     """Gets board temperature
 
     Parameters
@@ -788,7 +867,9 @@ def MPS_ProbeTemperature(sensor: TemperatureSensor) -> float:
         c_uint8(sensor)))
 
 
-def MPS_Beep(duration: float) -> None:
+def MPS_Beep(
+        duration: float
+        ) -> None:
     """Beeps the internal buzzer
 
     Parameters
@@ -813,7 +894,9 @@ class LicenseId(IntEnum):
     LICENSE_TERMINAL = 29
 
 
-def MPS_CouplerCheckLicense(embedded_license: LicenseId) -> bool:
+def MPS_CouplerCheckLicense(
+        embedded_license: LicenseId
+        ) -> bool:
     """Checks embedded license validity
 
     Parameters
@@ -854,6 +937,38 @@ def GetLastSystemErrorMessageEx() -> str:
     return message.value.decode('ascii').strip()
 
 
+def GetRemoteHelp(
+        remote: Optional[str] = None
+        ) -> Dict[str, str]:
+    """Gets remote command help message
+
+    Parameters
+    ----------
+    remote : str, optional
+        Remote command
+
+    Returns
+    -------
+    dict
+        Command/Description pairs
+    """
+    if remote and (not isinstance(remote, str) or len(remote) != 4):
+        raise TypeError('remote must be an instance of 4 characters string')
+    max_size = 3 * 1024 * 1024
+    message = create_string_buffer(max_size)
+    CTS3Exception._check_error(_MPuLib.GetRemoteHelp(
+        remote.encode('ascii') if remote else None,
+        message))
+    help: Dict[str, str] = {}
+    for cmd in message.value.decode('ascii').strip().split(';'):
+        pair = cmd.split('=')
+        if len(pair) == 1 and len(pair[0]):
+            help[pair[0]] = ''
+        elif len(pair) == 2 and len(pair[0]):
+            help[pair[0]] = pair[1]
+    return help
+
+
 def Reboot() -> None:
     """Reboots the device"""
     try:
@@ -885,7 +1000,9 @@ def Shutdown() -> None:
 # region Timers and time delay
 
 
-def MPS_DoTempo(delay: float) -> None:
+def MPS_DoTempo(
+        delay: float
+        ) -> None:
     """Waits for a delay
 
     Parameters
@@ -959,7 +1076,9 @@ def MPS_GetTime() -> datetime:
     return local_time
 
 
-def MPS_SetTime(time: datetime = datetime.now().astimezone()) -> None:
+def MPS_SetTime(
+        time: datetime = datetime.now().astimezone()
+        ) -> None:
     """Sets system time
 
     Parameters
@@ -998,7 +1117,9 @@ def MPS_GetTimeZone() -> str:
     return time_zone.value.decode('ascii')
 
 
-def MPS_SetTimeZone(time_zone: Optional[str] = None) -> None:
+def MPS_SetTimeZone(
+        time_zone: Optional[str] = None
+        ) -> None:
     """Sets time zone
 
     Parameters
@@ -1032,7 +1153,9 @@ def MPS_GetDate() -> datetime:
     return MPS_GetTime()
 
 
-def MPS_SetDate(date: datetime = datetime.now().astimezone()) -> None:
+def MPS_SetDate(
+        date: datetime = datetime.now().astimezone()
+        ) -> None:
     """Sets system date
 
     Parameters
@@ -1060,7 +1183,9 @@ class LedColor(IntEnum):
     LED_CYAN = 7
 
 
-def MPS_LedOn(color: LedColor) -> None:
+def MPS_LedOn(
+        color: LedColor
+        ) -> None:
     """Switches AUX CPU LED on
 
     Parameters
@@ -1085,7 +1210,10 @@ def MPS_LedOff() -> None:
 # region I²C
 
 
-def MPS_I2cAuxWrite(slave_address: int, data: bytes) -> None:
+def MPS_I2cAuxWrite(
+        slave_address: int,
+        data: bytes
+        ) -> None:
     """Writes to I²C AUX 2 front connector
 
     Parameters
@@ -1105,7 +1233,10 @@ def MPS_I2cAuxWrite(slave_address: int, data: bytes) -> None:
         data))
 
 
-def MPS_I2cAuxRead(slave_address: int, data_length: int) -> bytes:
+def MPS_I2cAuxRead(
+        slave_address: int,
+        data_length: int
+        ) -> bytes:
     """Reads from I²C AUX 2 front connector
 
     Parameters
@@ -1131,7 +1262,10 @@ def MPS_I2cAuxRead(slave_address: int, data_length: int) -> bytes:
     return data[:size.value]
 
 
-def MPS_I2cAux1Write(slave_address: int, data: bytes) -> None:
+def MPS_I2cAux1Write(
+        slave_address: int,
+        data: bytes
+        ) -> None:
     """Writes to I²C AUX 1 front connector
 
     Parameters
@@ -1151,7 +1285,10 @@ def MPS_I2cAux1Write(slave_address: int, data: bytes) -> None:
         data))
 
 
-def MPS_I2cAux1Read(slave_address: int, data_length: int) -> bytes:
+def MPS_I2cAux1Read(
+        slave_address: int,
+        data_length: int
+        ) -> bytes:
     """Reads from I²C AUX 1 front connector
 
     Parameters
@@ -1200,11 +1337,13 @@ class SerialParity(IntEnum):
     SERIAL_ODDP = 2
 
 
-def MPS_PortInit(baud_rate: Baudrate = Baudrate.BAUDS_115200,
-                 parity: SerialParity = SerialParity.SERIAL_NOP,
-                 stop_bits: int = 1,
-                 data_bits: int = 8,
-                 xon_xoff: bool = False) -> None:
+def MPS_PortInit(
+        baud_rate: Baudrate = Baudrate.BAUDS_115200,
+        parity: SerialParity = SerialParity.SERIAL_NOP,
+        stop_bits: int = 1,
+        data_bits: int = 8,
+        xon_xoff: bool = False
+        ) -> None:
     """Initializes serial port on AUX.CPU front connector
 
     Parameters
@@ -1241,7 +1380,9 @@ def MPS_PortInit(baud_rate: Baudrate = Baudrate.BAUDS_115200,
         c_uint8(flag)))
 
 
-def MPS_PortSend(tx_frame: bytes) -> None:
+def MPS_PortSend(
+        tx_frame: bytes
+        ) -> None:
     """Sends data over serial port
 
     Parameters
@@ -1258,7 +1399,9 @@ def MPS_PortSend(tx_frame: bytes) -> None:
         c_uint16(len(tx_frame))))
 
 
-def MPS_PortReceive(data_count: Optional[int] = None) -> bytes:
+def MPS_PortReceive(
+        data_count: Optional[int] = None
+        ) -> bytes:
     """Reads data from serial port
 
     Parameters
@@ -1299,7 +1442,9 @@ class PortStatusType(IntEnum):
     PS_TXBUFF_COUNT = 2
 
 
-def MPS_PortStatusEx(status_type: PortStatusType) -> int:
+def MPS_PortStatusEx(
+        status_type: PortStatusType
+        ) -> int:
     """Gets port buffer status
 
     Parameters
@@ -1337,7 +1482,10 @@ class AuxRelay(IntEnum):
     RELAY5 = 5
 
 
-def MPC_SetRelay(relay_number: AuxRelay, state: bool) -> None:
+def MPC_SetRelay(
+        relay_number: AuxRelay,
+        state: bool
+        ) -> None:
     """Drives a CMOS output on the HDMI connector
 
     Parameters
@@ -1352,7 +1500,7 @@ def MPC_SetRelay(relay_number: AuxRelay, state: bool) -> None:
     CTS3Exception._check_error(_MPuLib.MPC_SetRelay(
         c_uint8(0),
         c_uint8(relay_number),
-        c_uint8(1) if state else c_uint8(0)))
+        c_bool(state)))
 
 # endregion
 
@@ -1367,12 +1515,13 @@ class EmbeddedScriptMode(IntFlag):
     EMBEDDED_REMOTE_OUTPUT = 2
 
 
-def LaunchEmbeddedScript(script_command: str,
-                         timeout: float,
-                         option: EmbeddedScriptMode =
-                         EmbeddedScriptMode.EMBEDDED_WAIT_TERMINATION,
-                         call_back: Optional[Callable[[bytes], int]] =
-                         None) -> int:
+def LaunchEmbeddedScript(
+        script_command: str,
+        timeout: float,
+        option: EmbeddedScriptMode =
+        EmbeddedScriptMode.EMBEDDED_WAIT_TERMINATION,
+        call_back: Optional[Callable[[bytes], int]] = None
+        ) -> int:
     """Launches an embedded script
 
     Parameters
@@ -1410,9 +1559,11 @@ def LaunchEmbeddedScript(script_command: str,
     return retCode.value
 
 
-def StartEmbeddedApplication(application_path: str, args: str,
-                             call_back: Optional[Callable[[bytes], int]]
-                             = None) -> None:
+def StartEmbeddedApplication(
+        application_path: str,
+        args: str,
+        call_back: Optional[Callable[[bytes], int]] = None
+        ) -> None:
     """Launches an embedded C program within the firmware environment
 
     Parameters
@@ -1436,8 +1587,11 @@ def StartEmbeddedApplication(application_path: str, args: str,
 # region MPuLib Specific
 
 
-def OpenCommunication(host: Union[str, IPv4Address],
-                      log: bool = True) -> None:
+def OpenCommunication(
+        host: Union[str,
+                    IPv4Address],
+        log: bool = True
+        ) -> None:
     """Opens the communication channel to a CTS3
 
     Parameters
@@ -1471,13 +1625,17 @@ def CloseCommunication() -> None:
 class LibraryParameter(IntEnum):
     """MPuLib parameters"""
     TCP_TIMEOUT = 1
+    USB_TIMEOUT = 8
     DLL_VERSION = 10
     TCP_CONNECT_TIMEOUT = 12
     SPY_TIMEOUT = 13
     DAQ_TIMEOUT = 14
 
 
-def SetDLLParameter(param: LibraryParameter, value: float) -> None:
+def SetDLLParameter(
+        param: LibraryParameter,
+        value: float
+        ) -> None:
     """Sets MPuLib parameter
 
     Parameters
@@ -1497,7 +1655,9 @@ def SetDLLParameter(param: LibraryParameter, value: float) -> None:
         c_uint32(value_ms)))
 
 
-def GetDLLParameter(param: LibraryParameter) -> Union[str, float]:
+def GetDLLParameter(
+        param: LibraryParameter
+        ) -> Union[str, float]:
     """Gets MPuLib parameter
 
     Parameters
@@ -1518,33 +1678,47 @@ def GetDLLParameter(param: LibraryParameter) -> Union[str, float]:
         c_uint32(param),
         byref(val)))
     if param == LibraryParameter.DLL_VERSION:
-        return str(val.value >> 24) + '.' + str((val.value >> 16) & 0xFF) + \
-            '.' + str((val.value >> 8) & 0xFF) + '.' + \
-            str(val.value & 0xFF)
+        return (f'{val.value >> 24}.{(val.value >> 16) & 0xFF}.'
+                f'{(val.value >> 8) & 0xFF}.{val.value & 0xFF}')
     else:
         return float(val.value) / 1e3
 
 
-def SetDLLDebugMode(path: Optional[str]) -> None:
+def SetDLLDebugMode(
+        path: Union[str,
+                    Path,
+                    None]
+        ) -> None:
     """Generates a log file containing remote commands
 
     Parameters
     ----------
-    path : str
+    path : str or Path
         Log file path (None to deactivate)
     """
-    _MPuLib.SetDLLDebugMode.restype = None
-    if path is None or len(path) == 0:
-        _MPuLib.SetDLLDebugMode(
-            c_uint8(0), None)
+    if not path:
+        file = None
+    elif isinstance(path, Path):
+        if str(path) != '.':
+            file = str(path).encode('ascii')
+        else:
+            file = None
     else:
-        _MPuLib.SetDLLDebugMode(
-            c_uint8(1),
-            path.encode('ascii'))
+        if len(path) == 0:
+            file = None
+        else:
+            file = path.encode('ascii')
+    _MPuLib.SetDLLDebugMode.restype = None
+    _MPuLib.SetDLLDebugMode(
+        c_bool(file is not None),
+        file)
 
 
-def SendFrame(command: Optional[str], timeout: int = -1,
-              asynchronous_tx: bool = False) -> Optional[str]:
+def SendFrame(
+        command: Optional[str],
+        timeout: int = -1,
+        asynchronous_tx: bool = False
+        ) -> Optional[str]:
     """Sends a remote command to the connected CTS3
 
     Parameters
@@ -1604,7 +1778,9 @@ class LibraryMode(IntEnum):
     ADDRESSED = 2
 
 
-def SetDLLMode(mode: LibraryMode) -> None:
+def SetDLLMode(
+        mode: LibraryMode
+        ) -> None:
     """Sets MPuLib working mode
 
     Parameters
@@ -1637,6 +1813,28 @@ def USBEnumerateDevices() -> List[str]:
     return list_string.splitlines() if len(list_string) else []
 
 
+def UsbResetInterface(
+        host: Optional[str] = None
+        ) -> None:
+    """Resets WinUSB driver interface
+
+    Parameters
+    ----------
+    host : str, optional
+        Host name
+    """
+    if sys.platform == 'win32':
+        _MPuLib.UsbResetInterface.restype = None
+        if host is None:
+            _MPuLib.UsbResetInterface(
+                None,
+                c_uint32(0))
+        else:
+            _MPuLib.UsbResetInterface(
+                host.encode('ascii'),
+                c_uint32(0))
+
+
 def TCPEnumerateDevices() -> Dict[str, IPv4Address]:
     """Detects Micropross devices over Ethernet
 
@@ -1673,7 +1871,9 @@ def USBEnumerateDevices2() -> List[str]:
     return USBEnumerateDevices()
 
 
-def SelectActiveDevice(active_device: int) -> None:
+def SelectActiveDevice(
+        active_device: int
+        ) -> None:
     """Selects the device to send the commands to
 
     Parameters
@@ -1687,7 +1887,10 @@ def SelectActiveDevice(active_device: int) -> None:
         c_uint32(active_device)))
 
 
-def AbortCoupler(host: Union[str, IPv4Address]) -> None:
+def AbortCoupler(
+        host: Union[str,
+                    IPv4Address]
+        ) -> None:
     """Aborts current command execution
 
     Parameters
@@ -1707,33 +1910,49 @@ def AbortCoupler(host: Union[str, IPv4Address]) -> None:
         raise TypeError('host must be an instance of str or IPv4Interface')
 
 
-def UploadClientFile(local_path: str, remote_name: str) -> None:
+def UploadClientFile(
+        local_path: Union[str,
+                          Path],
+        remote_name: str
+        ) -> None:
     """Uploads a file to the CTS3 '/home/default/tmp' directory
 
     Parameters
     ----------
-    local_path : str
+    local_path : str or Path
         Path to file to upload
     remote_name : str
         CTS3 remote file name (will be over-written if already exists)
     """
+    if isinstance(local_path, Path):
+        file = str(local_path).encode('ascii')
+    else:
+        file = local_path.encode('ascii')
     CTS3Exception._check_error(_MPuLib.UploadClientFile(
-        local_path.encode('ascii'),
+        file,
         remote_name.encode('ascii')))
 
 
-def DownloadClientFile(remote_name: str, local_path: str) -> None:
+def DownloadClientFile(
+        remote_name: str,
+        local_path: Union[str,
+                          Path]
+        ) -> None:
     """Downloads a file from the CTS3 '/home/default/tmp' directory
 
     Parameters
     ----------
     remote_name : str
         CTS3 remote file name
-    local_path : str
+    local_path : str or Path
         Path to file to be downloaded
     """
+    if isinstance(local_path, Path):
+        file = str(local_path).encode('ascii')
+    else:
+        file = local_path.encode('ascii')
     CTS3Exception._check_error(_MPuLib.DownloadClientFile(
         remote_name.encode('ascii'),
-        local_path.encode('ascii')))
+        file))
 
 # endregion
